# TrainerSupervised

The `TrainerSupervised` class is part of the `jarvais.trainer` module.

::: jarvais.trainer.TrainerSupervised
    options:
        heading_level: 3
        members_order: source
        show_root_heading: true
